[![Build Status](https://travis-ci.org/boundlessgeo/lib-qgis-commons.svg?branch=master)](https://travis-ci.org/boundlessgeo/lib-qgis-commons)

# lib-qgis-commons
Common functions and classes to be used in QGIS plugins
